<div align="center">
    <img src="../../docs/images/logo-title.png" height="80px">
    <h3>The Graph Of LIfe Library.</h3>
</div>


## What is in this folder? 

code for the metric, training and trainer

- ✅ `predictor.py`: the `PredictorModule` class is the main class for the trainer 
- `metrics.py`: metrics for the task heads 
- `predictor_options.py`: options for the predictor, intervals, tracking min/max etc. 
- `predictor_summaries.py`: summaries for the task to track loss and metric
